@@ -21,7 +21,7 @@ using System;
 
 namespace OpenQA.Selenium.BiDi.Communication;
 
-public record CommandOptions
+public abstract class CommandOptions
 {
     public TimeSpan? Timeout { get; set; }
 }
