@@ -17,24 +17,18 @@
 // under the License.
 // </copyright>
 
-using System.Text.Json;
-
 namespace OpenQA.Selenium.BiDi.Communication;
 
-// https://github.com/dotnet/runtime/issues/72604
-//[JsonPolymorphic(TypeDiscriminatorPropertyName = "type")]
-//[JsonDerivedType(typeof(MessageSuccess), "success")]
-//[JsonDerivedType(typeof(MessageError), "error")]
-//[JsonDerivedType(typeof(MessageEvent), "event")]
 internal abstract record Message;
 
-internal record MessageSuccess(int Id, JsonElement Result) : Message;
+internal record MessageSuccess(long Id, EmptyResult Result) : Message;
 
-internal record MessageError(int Id) : Message
+internal record MessageError(long Id) : Message
 {
     public string? Error { get; set; }
 
     public string? Message { get; set; }
 }
 
-internal record MessageEvent(string Method, JsonElement Params) : Message;
+internal record MessageEvent(string Method, EventArgs Params) : Message;
+
