@@ -17,16 +17,15 @@
 // under the License.
 // </copyright>
 
-namespace OpenQA.Selenium
+namespace OpenQA.Selenium;
+
+/// <summary>
+/// Defines the interface through which the user can access the driver used to find an element.
+/// </summary>
+public interface IWrapsDriver
 {
     /// <summary>
-    /// Defines the interface through which the user can access the driver used to find an element.
+    /// Gets the <see cref="IWebDriver"/> used to find this element.
     /// </summary>
-    public interface IWrapsDriver
-    {
-        /// <summary>
-        /// Gets the <see cref="IWebDriver"/> used to find this element.
-        /// </summary>
-        IWebDriver WrappedDriver { get; }
-    }
+    IWebDriver WrappedDriver { get; }
 }
