@@ -19,20 +19,19 @@
 
 using Newtonsoft.Json;
 
-namespace OpenQA.Selenium.Environment
+namespace OpenQA.Selenium.Environment;
+
+[JsonObject]
+public class TestWebServerConfig
 {
-    [JsonObject]
-    public class TestWebServerConfig
-    {
-        [JsonProperty]
-        public bool CaptureConsoleOutput { get; set; }
+    [JsonProperty]
+    public bool CaptureConsoleOutput { get; set; }
 
-        [JsonProperty]
-        public bool HideCommandPromptWindow { get; set; }
+    [JsonProperty]
+    public bool HideCommandPromptWindow { get; set; }
 
-        [JsonProperty]
-        public string JavaHomeDirectory { get; set; }
+    [JsonProperty]
+    public string JavaHomeDirectory { get; set; }
 
-        public string Port { get; set; }
-    }
+    public string Port { get; set; }
 }
