@@ -20,7 +20,6 @@ package org.openqa.selenium.firefox;
 import static java.util.stream.Collectors.toMap;
 import static org.openqa.selenium.remote.Browser.FIREFOX;
 
-import java.io.File;
 import java.io.IOException;
 import java.io.UncheckedIOException;
 import java.nio.file.Path;
@@ -30,8 +29,6 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.Objects;
-import java.util.Optional;
 import java.util.Set;
 import java.util.TreeMap;
 import java.util.TreeSet;
@@ -149,32 +146,6 @@ public class FirefoxOptions extends AbstractDriverOptions<FirefoxOptions> {
     return this;
   }
 
-  /**
-   * Constructs a {@link FirefoxBinary} and returns that to be used, and because of this is only
-   * useful when actually starting firefox.
-   *
-   * @deprecated This method is deprecated and will be removed in a future version. Selenium Manager
-   *     handles this for you.
-   */
-  @Deprecated
-  public FirefoxBinary getBinary() {
-    return getBinaryOrNull().orElseGet(FirefoxBinary::new);
-  }
-
-  /**
-   * Sets the path to the Firefox binary to use. This is useful when you have multiple versions of
-   * Firefox installed on your machine.
-   *
-   * @deprecated This method is deprecated and will be removed in a future version. Use {@link
-   *     #setBinary(Path)} or {@link #setBinary(String)} instead.
-   */
-  @Deprecated
-  public FirefoxOptions setBinary(FirefoxBinary binary) {
-    Require.nonNull("Binary", binary);
-    addArguments(binary.getExtraOptions());
-    return setFirefoxOption(Keys.BINARY, binary.getPath());
-  }
-
   public FirefoxOptions setBinary(Path path) {
     Require.nonNull("Binary", path);
     return setFirefoxOption(Keys.BINARY, path.toString());
@@ -185,33 +156,6 @@ public class FirefoxOptions extends AbstractDriverOptions<FirefoxOptions> {
     return setFirefoxOption(Keys.BINARY, path);
   }
 
-  /**
-   * Returns the binary as a {@link FirefoxBinary} if it was set, or an empty {@link Optional} if
-   * not.
-   *
-   * @deprecated This method is deprecated and will be removed in a future version. Selenium Manager
-   *     handles this for you.}
-   */
-  @Deprecated
-  public Optional<FirefoxBinary> getBinaryOrNull() {
-    Object binary = firefoxOptions.get(Keys.BINARY.key());
-    if (!(binary instanceof String)) {
-      return Optional.empty();
-    }
-
-    FirefoxBinary toReturn = new FirefoxBinary(new File((String) binary));
-    Object rawArgs = firefoxOptions.getOrDefault(Keys.ARGS.key(), new ArrayList<>());
-    Require.stateCondition(rawArgs instanceof List, "Arguments are not a list: %s", rawArgs);
-
-    ((List<?>) rawArgs)
-        .stream()
-            .filter(Objects::nonNull)
-            .map(String::valueOf)
-            .forEach(toReturn::addCommandLineOptions);
-
-    return Optional.of(toReturn);
-  }
-
   public FirefoxProfile getProfile() {
     Object rawProfile = firefoxOptions.get(Keys.PROFILE.key());
     if (rawProfile == null) {
@@ -387,8 +331,6 @@ public class FirefoxOptions extends AbstractDriverOptions<FirefoxOptions> {
           newInstance.setBinary((String) binary);
         } else if (binary instanceof Path) {
           newInstance.setBinary((Path) binary);
-        } else if (binary instanceof FirefoxBinary) {
-          newInstance.setBinary((FirefoxBinary) binary);
         }
       }
 
@@ -435,8 +377,6 @@ public class FirefoxOptions extends AbstractDriverOptions<FirefoxOptions> {
           newInstance.setBinary((String) binary);
         } else if (binary instanceof Path) {
           newInstance.setBinary((Path) binary);
-        } else if (binary instanceof FirefoxBinary) {
-          newInstance.setBinary((FirefoxBinary) binary);
         }
 
         prefs.forEach(newInstance::addPreference);
@@ -512,12 +452,7 @@ public class FirefoxOptions extends AbstractDriverOptions<FirefoxOptions> {
       @Override
       public void amend(Map<String, Object> sourceOptions, Map<String, Object> toAmend) {
         Object o = sourceOptions.get(key());
-
-        if (o instanceof FirefoxBinary) {
-          FirefoxBinary binary = (FirefoxBinary) o;
-          toAmend.put(key(), binary.getFile().toString());
-          ARGS.amend(Collections.singletonMap(ARGS.key(), binary.getExtraOptions()), toAmend);
-        } else if (o instanceof String) {
+        if (o instanceof String) {
           toAmend.put(key(), o);
         }
       }
