@@ -91,6 +91,7 @@ public class DockerSessionFactory implements SessionFactory {
   private final Tracer tracer;
   private final HttpClient.Factory clientFactory;
   private final Duration sessionTimeout;
+  private final Duration serverStartTimeout;
   private final Docker docker;
   private final URI dockerUri;
   private final Image browserImage;
@@ -108,6 +109,7 @@ public class DockerSessionFactory implements SessionFactory {
       Tracer tracer,
       HttpClient.Factory clientFactory,
       Duration sessionTimeout,
+      Duration serverStartTimeout,
       Docker docker,
       URI dockerUri,
       Image browserImage,
@@ -123,6 +125,7 @@ public class DockerSessionFactory implements SessionFactory {
     this.tracer = Require.nonNull("Tracer", tracer);
     this.clientFactory = Require.nonNull("HTTP client", clientFactory);
     this.sessionTimeout = Require.nonNull("Session timeout", sessionTimeout);
+    this.serverStartTimeout = Require.nonNull("Server start timeout", serverStartTimeout);
     this.docker = Require.nonNull("Docker command", docker);
     this.dockerUri = Require.nonNull("Docker URI", dockerUri);
     this.browserImage = Require.nonNull("Docker browser image", browserImage);
@@ -181,7 +184,7 @@ public class DockerSessionFactory implements SessionFactory {
               "Waiting for server to start (container id: %s, url %s)",
               container.getId(), remoteAddress));
       try {
-        waitForServerToStart(client, Duration.ofMinutes(1));
+        waitForServerToStart(client, serverStartTimeout);
       } catch (TimeoutException e) {
         span.setAttribute(AttributeKey.ERROR.getKey(), true);
         span.setStatus(Status.CANCELLED);
@@ -286,7 +289,15 @@ public class DockerSessionFactory implements SessionFactory {
   }
 
   private Container createBrowserContainer(int port, Capabilities sessionCapabilities) {
-    Map<String, String> browserContainerEnvVars = getBrowserContainerEnvVars(sessionCapabilities);
+    Map<String, String> browserContainerEnvVars = new HashMap<>();
+    // Enable env var to trigger video recording if session capabilities request and external video
+    // container is disabled
+    if (videoImage == null && recordVideoForSession(sessionCapabilities)) {
+      browserContainerEnvVars.put("SE_RECORD_VIDEO", "true");
+      browserContainerEnvVars.put("SE_VIDEO_FILE_NAME", "auto");
+      browserContainerEnvVars.put("SE_VIDEO_RECORD_STANDALONE", "true");
+    }
+    browserContainerEnvVars.putAll(getBrowserContainerEnvVars(sessionCapabilities));
     long browserContainerShmMemorySize = 2147483648L; // 2GB
     ContainerConfig containerConfig =
         image(browserImage)
@@ -295,6 +306,10 @@ public class DockerSessionFactory implements SessionFactory {
             .network(networkName)
             .devices(devices)
             .applyHostConfig(hostConfig, hostConfigKeys);
+    Optional<DockerAssetsPath> path = ofNullable(this.assetsPath);
+    if (path.isPresent() && videoImage == null && recordVideoForSession(sessionCapabilities)) {
+      containerConfig.bind(Collections.singletonMap(this.assetsPath.getHostPath(), "/videos"));
+    }
     if (!runningInDocker) {
       containerConfig = containerConfig.map(Port.tcp(4444), Port.tcp(port));
     }
@@ -335,7 +350,7 @@ public class DockerSessionFactory implements SessionFactory {
 
   private Container startVideoContainer(
       Capabilities sessionCapabilities, String browserContainerIp, String hostPath) {
-    if (!recordVideoForSession(sessionCapabilities)) {
+    if (videoImage == null || !recordVideoForSession(sessionCapabilities)) {
       return null;
     }
     int videoPort = 9000;
@@ -355,7 +370,7 @@ public class DockerSessionFactory implements SessionFactory {
         clientFactory.createClient(ClientConfig.defaultConfig().baseUri(videoContainerUrl));
     try {
       LOG.fine(String.format("Waiting for video recording... (id: %s)", videoContainer.getId()));
-      waitForServerToStart(videoClient, Duration.ofMinutes(1));
+      waitForServerToStart(videoClient, serverStartTimeout);
     } catch (Exception e) {
       videoContainer.stop(Duration.ofSeconds(10));
       String message =
@@ -454,9 +469,8 @@ public class DockerSessionFactory implements SessionFactory {
     String capsToJson = new Json().toJson(sessionRequestCapabilities);
     try {
       Files.createDirectories(Paths.get(path));
-      Files.write(
-          Paths.get(path, "sessionCapabilities.json"),
-          capsToJson.getBytes(Charset.defaultCharset()));
+      Files.writeString(
+          Paths.get(path, "sessionCapabilities.json"), capsToJson, Charset.defaultCharset());
     } catch (IOException e) {
       LOG.log(Level.WARNING, "Failed to save session capabilities", e);
     }
