@@ -22,6 +22,7 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
+import org.jspecify.annotations.NullMarked;
 import org.openqa.selenium.By;
 import org.openqa.selenium.NoSuchElementException;
 import org.openqa.selenium.SearchContext;
@@ -38,6 +39,7 @@ import org.openqa.selenium.WebElement;
  * will find all elements that match <var>by2</var> and appear under an element that matches
  * <var>by1</var>.
  */
+@NullMarked
 public class ByChained extends By implements Serializable {
 
   private static final long serialVersionUID = 1563769051170172451L;
