@@ -296,68 +296,6 @@ module Selenium
           execute :take_element_screenshot, id: element
         end
 
-        #
-        # HTML 5
-        #
-
-        def local_storage_item(key, value = nil)
-          WebDriver.logger.deprecate('local_storage_item(key, value)', id: :local_storage_item)
-          if value
-            execute_script("localStorage.setItem('#{key}', '#{value}')")
-          else
-            execute_script("return localStorage.getItem('#{key}')")
-          end
-        end
-
-        def remove_local_storage_item(key)
-          WebDriver.logger.deprecate('remove_local_storage_item(key)', id: :remove_local_storage_item)
-          execute_script("localStorage.removeItem('#{key}')")
-        end
-
-        def local_storage_keys
-          WebDriver.logger.deprecate('local_storage_keys', id: :local_storage_keys)
-          execute_script('return Object.keys(localStorage)')
-        end
-
-        def clear_local_storage
-          WebDriver.logger.deprecate('clear_local_storage', id: :clear_local_storage)
-          execute_script('localStorage.clear()')
-        end
-
-        def local_storage_size
-          WebDriver.logger.deprecate('local_storage_size', id: :local_storage_size)
-          execute_script('return localStorage.length')
-        end
-
-        def session_storage_item(key, value = nil)
-          WebDriver.logger.deprecate('session_storage_item(key, value)', id: :session_storage_item)
-          if value
-            execute_script("sessionStorage.setItem('#{key}', '#{value}')")
-          else
-            execute_script("return sessionStorage.getItem('#{key}')")
-          end
-        end
-
-        def remove_session_storage_item(key)
-          WebDriver.logger.deprecate('remove_session_storage_item(key)', id: :remove_session_storage_item)
-          execute_script("sessionStorage.removeItem('#{key}')")
-        end
-
-        def session_storage_keys
-          WebDriver.logger.deprecate('session_storage_keys', id: :session_storage_keys)
-          execute_script('return Object.keys(sessionStorage)')
-        end
-
-        def clear_session_storage
-          WebDriver.logger.deprecate('clear_session_storage', id: :clear_session_storage)
-          execute_script('sessionStorage.clear()')
-        end
-
-        def session_storage_size
-          WebDriver.logger.deprecate('session_storage_size', id: :session_storage_size)
-          execute_script('return sessionStorage.length')
-        end
-
         #
         # javascript execution
         #
@@ -385,6 +323,8 @@ module Selenium
         end
 
         def delete_cookie(name)
+          raise ArgumentError, 'Cookie name cannot be null or empty' if name.nil? || name.to_s.strip.empty?
+
           execute :delete_cookie, name: name
         end
 
@@ -686,7 +626,7 @@ module Selenium
         end
 
         def escaper
-          @escaper ||= defined?(URI::Parser) ? URI::DEFAULT_PARSER : URI
+          @escaper ||= defined?(URI::RFC2396_PARSER) ? URI::RFC2396_PARSER : URI::DEFAULT_PARSER
         end
 
         def commands(command)
